@@ -17,11 +17,11 @@ use Win32::Unicode::Constant;
 use Win32::Unicode::Console;
 use Win32::Unicode::XS;
 
-our @EXPORT = qw/file_type file_size copyW moveW unlinkW touchW renameW statW/;
+our @EXPORT = qw/file_type file_size copyW moveW unlinkW touchW renameW statW utimeW/;
 our @EXPORT_OK = qw/filename_normalize slurp/;
 our %EXPORT_TAGS = ('all' => [@EXPORT, @EXPORT_OK]);
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 my %FILE_TYPE_ATTRIBUTES = (
     s => FILE_ATTRIBUTE_SYSTEM,
@@ -429,6 +429,20 @@ sub statW {
     ) : $result;
 }
 
+sub utimeW {
+    my ($atime, $mtime, @files) = @_;
+    $atime = $mtime = time if !defined $atime && !defined $mtime;
+    my $ret = 0;
+    for my $file (@files) {
+        $file = *$file->{_file_path} if blessed($file) && $file->isa('Win32::Unicode::File') && *$file->{_handle};
+        $file = cygpathw($file) or return if CYGWIN;
+        $file = catfile $file;
+        my $file_path = CYGWIN ? Encode::encode_utf8($file) : utf8_to_utf16($file) . NULL;
+        ++$ret if update_time($atime, $mtime, $file_path);
+    }
+    return $ret;
+}
+
 sub file_type {
     _croakW('Usage: type(attribute, file_or_dir_name)') unless @_ == 2;
     my $attr = shift;
@@ -844,7 +858,7 @@ Like shell command C<touch>.
 
   touchW $file or die $!;
 
-=item B<statW($file || $fh)>
+=item B<statW($file || $fh || $dir || $dh)>
 
 Like CORE::stat.
 
@@ -857,8 +871,25 @@ or
   my @stat = statW $fh or die $!;
   my $stat = statW $fh or die $!;
 
+or
+
+  my @stat = statW $dir or die $!;
+  my $stat = statW $dir or die $!;
+
+or
+
+  my $dh = Win32::Unicode::Dir->new->open($dir);
+  my @stat = statW $dh or die $!;
+  my $stat = statW $dh or die $!;
+
 If the array context, CORE:: stat like. However, scalar context case in hashref received.
 
+=item B<utimeW($atime, $mtime, $file || $fh)>
+
+Like CORE::utime.
+
+  my $rc = utime($atime, $mtime, $file, $fh);
+
 =item B<file_type('attribute', $file_or_dir)>
 
 Get windows file type
